# laygo2
(The commit history is cleaned up on 6-27-2022)

The LAYout with Gridded Object 2 (LAYGO2) is a layout generation framework
for custom integrated circuits.
LAYGO2 provides a rich and productive layout design environment for designers
with several advanced concepts such templates and grids.

For further documentation, see [./docs_workspace/](./docs_workspace/).

LAYGO2에 대한 상세한 설명은 다음 페이지를 참조하세요: [./docs_workspace/user_guide_kor/](./docs_workspace/user_guide_kor/)

Contributors: 
Jaeduk Han, Taeho Shin, Dongjun Lee, Dongwhee Kim, Gaeryun Sung, Wookjin Shin, Yunseong Jo, Hyungjoo Park, Seonghyun Park, Youngmin Oh, Taeseung Kang
